Installing Slik-wrangler — Slik Wrangler 1.0.1 documentation

# Installing Slik-wrangler

Slik-wrangler is available as a Python package for Linux, MacOS and Windows, and can be installed like any other Python package. You can visit our GitHub repository or get the latest version from PyPI

## Install in existing environment

If you have an existing Python environment activated, you can install Slik-wrangler with the command:

    >>> $ pip install slik-wrangler

## Install in a new virtual environment

To install Slik-wrangler in a virtual environment, you can use the Anaconda package.

You must have Miniconda or Anaconda Distribution installed.

Confirm you have Anaconda installed:

    >>> $ conda --version

Create new virtual environment and install Python 3.5 and above:

    >>> $ conda create -n yourenvname python=3.7

Activate your environment:

    >>> $ source activate yourenvname

Install Slik-wrangler and other packages you need for your project

    >>> $ pip install slik_wrangler

## Test your installation

    >>> $ python
        Python 3.7.5 (default, Oct 25 2019, 15:51:11)
        [GCC 7.3.0] :: Anaconda, Inc. on linux
    Type "help", "copyright", "credits" or "license" for more information.
    import Slik-wrangler

## What is this repository for